@@ -1,8 +1,10 @@
 from .cryptoolz import cryptoolz
+from .primes import primes
 from .keys import keys, create, reveal
 
 __all__ = [
     "cryptoolz",
+    "primes",
     "keys",
     "create",
     "reveal",
